/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright 2022-2024 RnD Center "ELVEES", JSC
 *
 */

#ifndef DT_BINDINGS_MCOM03_CLOCK_H
#define DT_BINDINGS_MCOM03_CLOCK_H

/* CPU PLL */
#define CLK_CPU_PLL0 0

/* CPU UCG */
#define CLK_CPU_UCG0_SYS 1
#define CLK_CPU_UCG0_CORE 2
#define CLK_CPU_UCG0_DBUS 3

#define CLK_CPU_NR_CLOCKS 4

/* SERVICE PLL */
#define CLK_SERVICE_PLL0 0

/* SERVICE UCG */
#define CLK_SERVICE_UCG0_APB 1
#define CLK_SERVICE_UCG0_CORE 2
#define CLK_SERVICE_UCG0_QSPI0 3
#define CLK_SERVICE_UCG0_BPAM 4
#define CLK_SERVICE_UCG0_RISC0 5
#define CLK_SERVICE_UCG0_MFBSP0 6
#define CLK_SERVICE_UCG0_MFBSP1 7
#define CLK_SERVICE_UCG0_MAILBOX0 8
#define CLK_SERVICE_UCG0_PVTCTR 9
#define CLK_SERVICE_UCG0_I2C4 10
#define CLK_SERVICE_UCG0_TRNG 11
#define CLK_SERVICE_UCG0_SPIOTP 12
#define CLK_SERVICE_UCG0_I2C4_EXT 13
#define CLK_SERVICE_UCG0_QSPI0_EXT 14
#define CLK_SERVICE_UCG0_CLKOUT_EXT 15
#define CLK_SERVICE_UCG0_RISC0_TCK 16

#define CLK_SERVICE_NR_CLOCKS 17

/* SDR PLL */
#define CLK_SDR_PLL0 0
#define CLK_SDR_PLL1 1
#define CLK_SDR_PLL2 2

/* SDR REFMUX */
#define CLK_SDR_REFMUX_PCIE0_REF 3
#define CLK_SDR_REFMUX_JESD0_TX 4
#define CLK_SDR_REFMUX_JESD0_RX 5
#define CLK_SDR_REFMUX_PCIE1_REF 6
#define CLK_SDR_REFMUX_JESD1_TX 7
#define CLK_SDR_REFMUX_JESD1_RX 8
#define CLK_SDR_REFMUX_N_DFE 9

/* SDR UCG0 */
#define CLK_SDR_UCG0_CFG 10
#define CLK_SDR_UCG0_EXT 11
#define CLK_SDR_UCG0_INT 12
#define CLK_SDR_UCG0_PCI 13
#define CLK_SDR_UCG0_VCUA 14
#define CLK_SDR_UCG0_ACC0 15
#define CLK_SDR_UCG0_ACC1 16
#define CLK_SDR_UCG0_ACC2 17
#define CLK_SDR_UCG0_AUX_PCI 18
#define CLK_SDR_UCG0_GNSS 19
#define CLK_SDR_UCG0_DFE_ALT 20
#define CLK_SDR_UCG0_VCU 21
#define CLK_SDR_UCG0_LVDS 22

/* SDR UCG_PCIE0_REF */
#define CLK_SDR_UCG_PCIE0_REF_ALT 23

/* SDR UCG_JESD0_TX */
#define CLK_SDR_UCG_JESD0_TX_SAMPLE 24
#define CLK_SDR_UCG_JESD0_TX_CHARACTER 25

/* SDR UCG_JESD0_RX */
#define CLK_SDR_UCG_JESD0_RX_SAMPLE 26
#define CLK_SDR_UCG_JESD0_RX_CHARACTER 27

/* SDR UCG_PCIE1_REF */
#define CLK_SDR_UCG_PCIE1_REF_ALT 28

/* SDR UCG_JESD1_TX */
#define CLK_SDR_UCG_JESD1_TX_SAMPLE 29
#define CLK_SDR_UCG_JESD1_TX_CHARACTER 30

/* SDR UCG_JESD1_RX */
#define CLK_SDR_UCG_JESD1_RX_SAMPLE 31
#define CLK_SDR_UCG_JESD1_RX_CHARACTER 32

/* SDR N_DFE */
#define CLK_SDR_UCG_N_DFE_DFE_N 33

/* SDR DSP GATE */
#define CLK_SDR_GATE_DSP0 34
#define CLK_SDR_GATE_DSP1 35

/* SDR PCIE GATE */
#define CLK_SDR_GATE_PCIE0 36
#define CLK_SDR_GATE_PCIE0_REF_ALT_P 37
#define CLK_SDR_GATE_PCIE0_REF_ALT_N 38
#define CLK_SDR_GATE_PCIE1 39
#define CLK_SDR_GATE_PCIE1_REF_ALT_P 40
#define CLK_SDR_GATE_PCIE1_REF_ALT_N 41

#define CLK_SDR_NR_CLOCKS 42

/* MEDIA PLL */
#define CLK_MEDIA_PLL0 0
#define CLK_MEDIA_PLL1 1
#define CLK_MEDIA_PLL2 2
#define CLK_MEDIA_PLL3 3

/* MEDIA UCG0 */
#define CLK_MEDIA_UCG0_SYSA 4
#define CLK_MEDIA_UCG0_ISP_SYS 5

/* MEDIA UCG1 */
#define CLK_MEDIA_UCG1_DISP_A 6
#define CLK_MEDIA_UCG1_DISP_M 7
#define CLK_MEDIA_UCG1_DISP_PXL 8

/* MEDIA UCG2 */
#define CLK_MEDIA_UCG2_GPU_SYS 9
#define CLK_MEDIA_UCG2_GPU_MEM 10
#define CLK_MEDIA_UCG2_GPU_CORE 11

/* MEDIA UCG3 */
#define CLK_MEDIA_UCG3_MIPI_RX_REF 12
#define CLK_MEDIA_UCG3_MIPI_RX0_CFG 13
#define CLK_MEDIA_UCG3_MIPI_RX1_CFG 14
#define CLK_MEDIA_UCG3_MIPI_TX_REF 15
#define CLK_MEDIA_UCG3_MIPI_TX_CFG 16
#define CLK_MEDIA_UCG3_CMOS0 17
#define CLK_MEDIA_UCG3_CMOS1 18
#define CLK_MEDIA_UCG3_MIPI_TXCLKESC 19
#define CLK_MEDIA_UCG3_VPU 20

#define CLK_MEDIA_NR_CLOCKS 21

/* DDR PLL */
#define CLK_DDR_PLL0 0
#define CLK_DDR_PLL1 1

/* DDR UCG0 */
#define CLK_DDR_UCG0_DDR0 2
#define CLK_DDR_UCG0_DDR0_X4 3
#define CLK_DDR_UCG0_DDR1 4
#define CLK_DDR_UCG0_DDR1_X4 5

/* DDR UCG1 */
#define CLK_DDR_UCG1_SYS 6
#define CLK_DDR_UCG1_SDR 7
#define CLK_DDR_UCG1_PCIE 8
#define CLK_DDR_UCG1_ISP 9
#define CLK_DDR_UCG1_GPU 10
#define CLK_DDR_UCG1_VPU 11
#define CLK_DDR_UCG1_DP 12
#define CLK_DDR_UCG1_CPU 13
#define CLK_DDR_UCG1_SERVICE 14
#define CLK_DDR_UCG1_HSPERIPH 15
#define CLK_DDR_UCG1_LSPERIPH0 16
#define CLK_DDR_UCG1_LSPERIPH1 17

#define CLK_DDR_NR_CLOCKS 18

/* HSP PLL */
#define CLK_HSP_PLL0 0

/* HSP REFMUX */
#define CLK_HSP_REFMUX0 4
#define CLK_HSP_REFMUX1 5
#define CLK_HSP_REFMUX2 6
#define CLK_HSP_REFMUX3 7

/* HSP UCG0 */
#define CLK_HSP_UCG0_SYS 8
#define CLK_HSP_UCG0_DMA 9
#define CLK_HSP_UCG0_CTR 10
#define CLK_HSP_UCG0_SPRAM 11
#define CLK_HSP_UCG0_EMAC0 12
#define CLK_HSP_UCG0_EMAC1 13
#define CLK_HSP_UCG0_USB0 14
#define CLK_HSP_UCG0_USB1 15
#define CLK_HSP_UCG0_NFC 16
#define CLK_HSP_UCG0_PDMA2 17
#define CLK_HSP_UCG0_SDMMC0 18
#define CLK_HSP_UCG0_SDMMC1 19
#define CLK_HSP_UCG0_QSPI 20

/* HSP UCG1 */
#define CLK_HSP_UCG1_SDMMC0_XIN 21
#define CLK_HSP_UCG1_SDMMC1_XIN 22
#define CLK_HSP_UCG1_NFC_FLASH 23
#define CLK_HSP_UCG1_QSPI_EXT 24
#define CLK_HSP_UCG1_UST 25

/* HSP UCG2 */
#define CLK_HSP_UCG2_EMAC0_1588 26
#define CLK_HSP_UCG2_EMAC0_RGMII_TXC 27
#define CLK_HSP_UCG2_EMAC1_1588 28
#define CLK_HSP_UCG2_EMAC1_RGMII_TXC 29

/* HSP UCG3 */
#define CLK_HSP_UCG3_USB0_REF_ALT 30
#define CLK_HSP_UCG3_USB0_SUSPEND 31
#define CLK_HSP_UCG3_USB1_REF_ALT 32
#define CLK_HSP_UCG3_USB1_SUSPEND 33

#define CLK_HSP_NR_CLOCKS 34

/* LSP0 PLL */
#define CLK_LSP0_PLL0 0

/* LSP0 UCG */
#define CLK_LSP0_UCG0_SYS 1
#define CLK_LSP0_UCG0_UART3 2
#define CLK_LSP0_UCG0_UART1 3
#define CLK_LSP0_UCG0_UART2 4
#define CLK_LSP0_UCG0_SPI0 5
#define CLK_LSP0_UCG0_I2C0 6
#define CLK_LSP0_UCG0_GPIO0_DB 7

#define CLK_LSP0_NR_CLOCKS 8

/* LSP1 PLL */
#define CLK_LSP1_PLL0 0

/* LSP1 REFMUX I2S */
#define CLK_LSP1_REFMUX_I2S 1

/* LSP1 UCG */
#define CLK_LSP1_UCG0_SYS 2
#define CLK_LSP1_UCG0_I2C1 3
#define CLK_LSP1_UCG0_I2C2 4
#define CLK_LSP1_UCG0_I2C3 5
#define CLK_LSP1_UCG0_GPIO1_DB 6
#define CLK_LSP1_UCG0_SSI1 7
#define CLK_LSP1_UCG0_UART0 8
#define CLK_LSP1_UCG0_TIMERS0 9
#define CLK_LSP1_UCG0_PWM0 10
#define CLK_LSP1_UCG0_WDT1 11

/* LSP1 I2S_UCG */
#define CLK_LSP1_UCG_I2S_I2S0 12

#define CLK_LSP1_NR_CLOCKS 13

#endif
